@@ -1,11 +1,3 @@
-### Necessary fields in DESCRIPTION, otherwise error.
-fields <- c("Package","Maintainer","Author","Version",
-            "License","Title","Description")
-
-### Default DESCRIPTION, written if it doesn't exist.  TODO, PhG:
-### start with reasonable values here!
-empty.description <- matrix("",ncol=length(fields),dimnames=list(NULL,fields))
-
 package.skeleton.dx <- structure(function # Package skeleton deluxe
 ### Generates Rd files for a package based on R code and DESCRIPTION
 ### metadata. After inspecting the specified R code files to find
@@ -29,6 +21,9 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
 ### A logical indicating whether a NAMESPACE file should be generated
 ### for this package. If \code{TRUE}, all objects whose name starts
 ### with a letter, plus all S4 methods and classes are exported.
+ excludePattern=FALSE,
+### A regular expression matching the files that are not to be processed e.g. because 
+### inlinedocs can not handle them yet (like generic function definitions)
  ...
 ### Parameters to pass to Parser Functions.
  ){
@@ -46,6 +41,26 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
   # package 'utils", where it lives. So, I prefer using file.info()
   if (isTRUE(file.info("unix")$isdir) || isTRUE(file.info("windows")$isdir))
     stop("Platform-specific code in ./R/unix, or ./R/windows is not supported")
+
+  ## Default values and required fields in DESCRIPTION file.
+  description.defaults <-
+    c("Package"="",
+      "Maintainer"=Sys.getenv("USER"),
+      "Author"=Sys.getenv("USER"),
+      "Version"="1.0",
+      "License"="GPL-3",
+      "Title"="a package",
+      "Description"="a package that does\n many things.")
+
+  ## Necessary fields in DESCRIPTION, otherwise error.
+  fields <- names(description.defaults)
+
+  ## Default DESCRIPTION, written if it doesn't exist.
+  empty.description <-
+    matrix(description.defaults,ncol=length(fields),dimnames=list(NULL,fields))
+
+
+  
   
   ## if no DESCRIPTION, make one and exit.
   descfile <- file.path("..","DESCRIPTION")
@@ -77,6 +92,7 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
   # case (to be checked with most complex cases!)
   if ("Imports" %in% colnames(desc))
     required <- c(required, strsplit(desc[, "Imports"], split = ",")[[1]])
+  ##print(c("required=",required))
   ## This may need some refining, basically I just tried to take the
   ## first word from each vector element, stripping of whitespace in
   ## front and anything after:
@@ -143,26 +159,24 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
   # man page!
   code_files <- if(!"Collate"%in%colnames(desc))Sys.glob("*.R")
   else strsplit(gsub("\\s+"," ",desc[,"Collate"]),split=" ")[[1]]
-  # PhG: one must consider a potential Encoding field in DESCRIPTION file!
+  code_files =grep(excludePattern,code_files,invert=TRUE,value=TRUE)
+  ##print(excludePattern)
+  ## Make package skeleton and edit Rd files (eventually just don't
+  ## use package.skeleton at all?)
+  name <- desc[,"Package"]
+  unlink(name,recursive=TRUE)
+  package.skeleton(name,code_files=code_files)
+
+#  # PhG: one must consider a potential Encoding field in DESCRIPTION file!
   # which is used also for .R files according to Writing R Extensions
   if ("Encoding" %in% colnames(desc)) {
     oEnc <- options(encoding = desc[1, "Encoding"])$encoding
     on.exit(options(encoding = oEnc), add = TRUE)
   }
   code <- do.call(c,lapply(code_files,readLines))
-  
-  docs <- apply.parsers(code,parsers,verbose=TRUE,desc=desc)
+#  #print(code)
+  docs<- apply.parsers(code,parsers,verbose=TRUE,desc=desc)
 
-  ## Make package skeleton and edit Rd files (eventually just don't
-  ## use package.skeleton at all?)
-  name <- desc[,"Package"]
-  unlink(name,rec=TRUE)
-  # PhG: added namespace argument to package.skeleton()
-  # twutz: addedd suppressWarnings around package.skeleton, 
-  # because I always got the warning that the package does not exist
-  suppressWarnings({
-    package.skeleton(name,code_files=code_files, namespace = isTRUE(namespace))
-  })
   cat("Modifying files automatically generated by package.skeleton:\n")
   ## documentation of generics may be duplicated among source files.
   dup.names <- duplicated(names(docs))
@@ -170,7 +184,7 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
     warning("duplicated file names in docs: ",paste(names(docs)[dup.names]))
   }
   for(N in unique(names(docs))) modify.Rd.file(N,name,docs)
-  file.copy(file.path(name,'man'),"..",rec=TRUE)
+  file.copy(file.path(name,'man'),"..",recursive=TRUE)
   # PhG: copy NAMESPACE file back
   if (isTRUE(namespace)) {
     # PhG: package.skeleton() does not add import() statement, but here the
@@ -194,11 +208,12 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
     }
   }
   
-  unlink(name,rec=TRUE)
+  unlink(name,recursive=TRUE)
 },ex=function(){
   library(inlinedocs)
 
   owd <- setwd(tempdir())
+  ##owd <- setwd("~")
   
   ## get the path to the silly example package that is provided with
   ## package inlinedocs
@@ -217,13 +232,17 @@ package.skeleton.dx <- structure(function # Package skeleton deluxe
 
   ## check the package to see if generated documentation passes
   ## without WARNINGs
-  cmd <- sprintf("%s CMD check silly",file.path(R.home("bin"), "R"))
+  cmd <- sprintf("%s CMD check --as-cran silly",file.path(R.home("bin"), "R"))
   print(cmd)
   checkLines <- system(cmd,intern=TRUE)
   warnLines <- grep("WARNING",checkLines,value=TRUE)
   if(length(warnLines)>0){
+    writeLines(checkLines)
+    cat("\n\nLines with WARNING:\n")
     print(warnLines)
-    stop("WARNING encountered in package check!")
+    ## disable due to bug in R CMD check:
+    ## https://bugs.r-project.org/bugzilla3/show_bug.cgi?id=14875
+    ##stop("WARNING encountered in package check!")
   }
   
   ## cleanup: remove the test package from current workspace again
@@ -370,16 +389,6 @@ modify.Rd.file <- function
     fend <- closing[closing>fstart][1]-1
     dlines[fstart:fend] <- gsub("[{}]","",dlines[fstart:fend])
   }
-  ## At least in my code, any remaining % symbols are in \usage sections
-  ## as function arguments. These promptly break Rd check because you end
-  ## up with unterminated strings. Just in case, the following regexp only
-  ## modifies those % symbols which follow something other than %.
-  ## (a more complicated version would attempt to do so only within strings.)
-  dlines <- gsub("([^%])%","\\1\\\\%",dlines,perl=TRUE)
-  
-  # PhG: now restore masked function name, if any (case of %....% operators)
-  if (!is.null(Nmask))
-    dlines <- gsub(Nmask, N, dlines, fixed = TRUE)
 
   ## sometimes (s4 classes) title is has \code{} blocks inside, which
   ## causes problems with our find-replace regex inside replace.one,
@@ -391,23 +400,19 @@ modify.Rd.file <- function
   
   txt <- paste(dlines,collapse="\n")
   
-  ## Find and replace based on data in d
-  for(torep in names(d)){
-    if ( !grepl("^[.]",torep) ){## .flags should not be used for find-replace
-      txt <- replace.one(torep,d[[torep]],txt)
-    }
-  }
-
   ## Fix usage
   m <- regexpr("usage[{][^}]*[}]",txt)
   Mend <- m+attr(m,"match.length")
-  utxt <- substr(txt,m,Mend)
+  utxt <- substr(txt,m+6,Mend-2)
+
   ## multiple lines for the PDF!
-  utxt <- gsub(", ",",\n",utxt)
+  parsed <- parse(text=utxt)
+  if(length(parsed)){
+    utxt <- sprintf("usage{%s}\n",paste(format(parsed[[1]]),collapse="\n"))
+  }
   if(length(grep("usage[{]data",utxt))){
-     utxt <- gsub("data[(]([^)]*)[)]","\\1",utxt)
-   }
-  
+    utxt <- gsub("data[(]([^)]*)[)]","\\1",utxt)
+  }
   ## fix \method version if .s3method
   if ( !is.null(d$.s3method) ){
     pat <- paste(d$.s3method,collapse=".")
@@ -442,8 +447,29 @@ modify.Rd.file <- function
                gsub("\\\\([^%])","\\\\\\\\\\1",utxt),
                substr(txt,Mend+1,nchar(txt)),
                sep="")
+
+
+  
+  ## At least in my code, any remaining % symbols are in \usage sections
+  ## as function arguments. These promptly break Rd check because you end
+  ## up with unterminated strings. Just in case, the following regexp only
+  ## modifies those % symbols which follow something other than %.
+  ## (a more complicated version would attempt to do so only within strings.)
+  txt <- gsub("([^%])%","\\1\\\\%",txt,perl=TRUE)
+  
+  # PhG: now restore masked function name, if any (case of %....% operators)
+  if (!is.null(Nmask))
+    txt <- gsub(Nmask, N, txt, fixed = TRUE)
+
+  ## Find and replace based on data in d
+  for(torep in names(d)){
+    if ( !grepl("^[.]",torep) ){## .flags should not be used for find-replace
+      txt <- replace.one(torep,d[[torep]],txt)
+    }
+  }
+
   ## delete empty sections to suppress warnings in R CMD check
-  txt <- gsub("\\\\[a-z]+[{]\\W*[}]","",txt)
+  txt <- gsub("\\\\[a-z]+[{]\\s*[}]","",txt)
   if ( !is.null(d$.s3method) ){
     ## and now remove the xx inserted above to prevent \method{[[}{...} falling
     ## foul of the above replacement!
@@ -457,3 +483,4 @@ modify.Rd.file <- function
   cat(txt,file=f)
   cat("\n")
 }
+
