@@ -75,11 +75,14 @@ make.package.and.check <- function
   rdir <- file.path(pkgdir,"R")
   if(verbose)print(rdir)
   dir.create(rdir,recursive=TRUE)
-  desc <- system.file(file.path("silly","DESCRIPTION"),package="inlinedocs")
-  file.copy(desc,pkgdir)
+  sillydir <- system.file("silly",package="inlinedocs")
+  tocopy <- file.path(sillydir,c("DESCRIPTION","NAMESPACE"))
+  file.copy(tocopy,pkgdir)
   file.copy(f,rdir)
   package.skeleton.dx(pkgdir,parsers)
-  cmd <- sprintf("%s CMD check %s",file.path(R.home("bin"), "R"),pkgdir)
+  cmd <- sprintf("%s CMD check --as-cran %s",
+                 file.path(R.home("bin"), "R"),
+                 pkgdir)
   if(verbose)cat(cmd,"\n")
   checkLines <- system(cmd,intern=TRUE)
   warnLines <- grep("(WARNING|ERROR)",checkLines,value=TRUE)
